<?php declare(strict_types=1);

/**
 * Add/Edit/Delete Feed Page
 *
 * Allows users to add, edit, and delete feeds
 */

use BitBadger\PDODocument\{Delete, DocumentException, Field};
use FeedReaderCentral\{Feed, Security, Table};
use GrahamCampbell\ResultType\Error;

include '../../start.php';

Security::verifyUser();

$feedId = key_exists('id', $_GET) ? (int)$_GET['id'] : -1;

if ($_SERVER['REQUEST_METHOD'] == 'DELETE') {
    try {
        $feed = Feed::retrieveById($feedId)->getOrCall(not_found(...));
        Delete::byFields(Table::ITEM, [Field::EQ('feed_id', $feed->id)]);
        Delete::byId(Table::FEED, $feed->id);
        add_info('Feed &ldquo;' . htmlentities($feed->title) . '&rdquo; deleted successfully');
        frc_redirect('/feeds');
    } catch (DocumentException $ex) {
        add_error("$ex");
    }
}

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    try {
        $isNew = $_POST['id'] == '-1';
        if ($isNew) {
            $result = Feed::add($_POST['url']);
        } else {
            $feedId = (int)$_POST['id'];
            $toEdit = Feed::retrieveById($feedId);
            $result = $toEdit->isDefined()
                ? Feed::update($toEdit->get(), $_POST['url'])
                : Error::create("Feed $feedId not found");
        }
        if ($result->success()->isDefined()) {
            add_info('Feed saved successfully');
            frc_redirect('/feeds');
        }
        add_error($result->error()->get());
        $feedId = 'error';
    } catch (DocumentException $ex) {
        add_error("$ex");
    }
}

if ($feedId == -1) {
    $title = 'Add RSS Feed';
    $feed  = new Feed(id: -1);
} else {
    $title = 'Edit RSS Feed';
    $feed = $feedId == 'error'
        ? new Feed(id: (int)$_POST['id'], url: $_POST['url'] ?? '')
        : Feed::retrieveById((int)$feedId)->getOrCall(not_found(...));
}

page_head($title); ?>
<h1><?=$title?></h1>
<article>
    <form method=POST action=/feed/ hx-post=/feed/>
        <input type=hidden name=id value=<?=$feed->id?>>
        <label>
            Feed URL
            <input type=url name=url required autofocus value="<?=$feed->url?>">
        </label>
        <span class=break></span>
        <button type=submit>Save</button>
    </form>
</article><?php
page_foot();
